@@ -32,7 +32,7 @@ except:
 __types_functions = None
 
 def types_functions():
-    """ utility function which returns all types.* considered function """
+    """ Returns all types.* considered function """
     global __types_functions
     if __types_functions is None:
         __types_functions = set()
@@ -77,11 +77,11 @@ def types_functions():
     return __types_functions
 
 def isFunction(f):
-    """ checks whether 'f' is a function in an extended sense. Check 'types_functions' for what is tested against"""
+    """ Checks whether 'f' is a function in an extended sense. Check 'types_functions' for what is tested against"""
     return isinstance(f,types_functions())
 
 def isAtomic( o ):
-    """ returns true if 'o' is a string, int, float, date or bool """
+    """ Returns true if 'o' is a string, int, float, date or bool """
     if type(o) in [str,int,bool,float,datetime.date]:
         return True
     if not np is None and isinstance(o,(np.float,np.int)):
@@ -89,7 +89,7 @@ def isAtomic( o ):
     return False
 
 def isFloat( o ):
-    """ checks whether a type is a float """
+    """ Checks whether a type is a float """
     if type(o) is float:
         return True
     if not np is None and isinstance(o,np.float):
@@ -113,20 +113,21 @@ def _fmt( text, args = None, kwargs = None ):
     return text
 
 def fmt(text,*args,**kwargs):
-    """ String formatting made easy
-            text - pattern
-        Examples
-            fmt("The is one = %ld", 1)
-            fmt("The is text = %s", 1.3)
-            fmt("Using keywords: one=%(one)d, two=%(two)d", two=2, one=1)
+    """
+    String formatting made easy
+        text - pattern
+    Examples
+        fmt("The is one = %ld", 1)
+        fmt("The is text = %s", 1.3)
+        fmt("Using keywords: one=%(one)d, two=%(two)d", two=2, one=1)
     """
     return _fmt(text,args,kwargs)
 
 def prnt(text,*args,**kwargs):
-    """ prints a fmt() string """
+    """ Prints a fmt() string """
     print(_fmt(text,args,kwargs))
 def write(text,*args,**kwargs):
-    """ prints a fmt() string without EOL """
+    """ Prints a fmt() string without EOL """
     print(_fmt(text,args,kwargs),end='')
 
 # =============================================================================
@@ -177,17 +178,18 @@ def plain( inn, sorted = False ):
     raise TypeError(fmt("Cannot handle type %s", type(inn)))
 
 def uniqueHash(*args, **kwargs):
-    """ Generates a hash key for any collection of python objects.
-        Typical use is for key'ing data vs a unique configuation.
-        
-        The function
-            1) uses the repr() function to feed objects to the hash algorithm.
-               that means is only distinguishes floats up to str conversion precision
-            2) keys of dictionaries, and sets are sorted to ensure equality of hashes
-               accross different memory setups of strings
-            3) Members with leading '_' are ignored
-        
-        Hans Buehler 2017
+    """ 
+    Generates a hash key for any collection of python objects.
+    Typical use is for key'ing data vs a unique configuation.
+    
+    The function
+        1) uses the repr() function to feed objects to the hash algorithm.
+           that means is only distinguishes floats up to str conversion precision
+        2) keys of dictionaries, and sets are sorted to ensure equality of hashes
+           accross different memory setups of strings
+        3) Members with leading '_' are ignored
+    
+    Hans Buehler 2017
     """    
     m = hashlib.md5()
     def update(s):
@@ -246,13 +248,13 @@ def uniqueHash(*args, **kwargs):
 # =============================================================================
 
 def f_eq_zero(x,prec,ref=1.):
-    """checks whether x is zero with precision prec*(ref+1.) """
+    """ Checks whether x is zero with precision prec*(ref+1.) """
     return abs(x) <= prec * (abs(ref) + 1.)
 def f_leq_zero(x,prec,ref=1.):
-    """checks whether x is smaller than zero with precision prec*(ref+1.) """
+    """ Checks whether x is smaller than zero with precision prec*(ref+1.) """
     return x <= prec * (abs(ref) + 1.)
 def f_geq_zero(x,prec,ref=1.):
-    """checks whether x is greater than zero with precision prec*(ref+1.) """
+    """ Checks whether x is greater than zero with precision prec*(ref+1.) """
     return x >= - prec * (abs(ref) + 1.)
 
 # =============================================================================
@@ -260,14 +262,15 @@ def f_geq_zero(x,prec,ref=1.):
 # =============================================================================
 
 def bind( F, **kwargs ):
-    """ Binds default named arguments to F.
-        For example
-            def F(x,y):
-                return x*y
-            Fx = bind(F,y=2.)
-            Fx(1.)             # x=1
-            Fx(1.,2.)          # x=1, y=2
-            Fx(1.,y=3.)        # x=1, y=3
+    """ 
+    Binds default named arguments to F.
+    For example
+        def F(x,y):
+            return x*y
+        Fx = bind(F,y=2.)
+        Fx(1.)             # x=1
+        Fx(1.,2.)          # x=1, y=2
+        Fx(1.,y=3.)        # x=1, y=3
     """
     kwargs_ = dict(kwargs)
     @wraps(F)
@@ -282,63 +285,62 @@ def bind( F, **kwargs ):
 # =============================================================================
 
 class Generic(object):
-    """ An object which can be used as a generic store.
-        Constructions by keyword:        
-            g = Generic(a=1, b=2, c=3)
-                        
-        Access by key        
-            a = g.a
-            a = g['a']
-            e = g.get('e',None)   # with default
-            e = g('e',None)       # with default
-            del g.e
-            
-        Such objects can be extended with functions e.g. you can set
-            def f(x):
-                return x*x
-            g.f = f
-            g.f(2) --> 4
+    """
+    An object which can be used as a generic store.
+    Constructions by keyword:        
+        g = Generic(a=1, b=2, c=3)
+                    
+    Access by key        
+        a = g.a
+        a = g['a']
+        e = g.get('e',None)   # with default
+        e = g('e',None)       # with default
+        del g.e
+        
+    Such objects can be extended with functions e.g. you can set
+        def f(x):
+            return x*x
+        g.f = f
+        g.f(2) --> 4
 
-        This works as well with bound functions, e.g. 
-            def F(self,a):
-                self.a = a            # set the value of the 'g' object
-            g.F = MethodType(F)
-            ...
-            g.F(1)
-            g.a --> 1
+    This works as well with bound functions, e.g. 
+        def F(self,a):
+            self.a = a            # set the value of the 'g' object
+        g.F = MethodType(F)
+        ...
+        g.F(1)
+        g.a --> 1
             
     Hans Buehler, 2013
     """
     
     def __init__(self, *vargs, **kwargs):
-        """ Initialize object; use keyword notation such as
-                Generic(a=1, b=2)                
-            The 'vargs' argument allows passing on existing Generic, dict or generic objects;
-            see update() for further information
+        """
+        Initialize object; use keyword notation such as
+            Generic(a=1, b=2)                
+        The 'vargs' argument allows passing on existing Generic, dict or generic objects;
+        see update() for further information
         """
         # allow construction the object as Generic(a=1,b=2)
         self.update(*vargs,**kwargs)
     
     # make it behave like a dictionary    
     
-    def __str__(self):
-        """ like dict """
+    def __str__(self):# NOQA
         return self.__dict__.__str__()
     
-    def __repr__(self):
-        """ like dict """
+    def __repr__(self):# NOQA
         return self.__dict__.__repr__()
     
-    def __getitem__(self,key):
-        """ like dict """
+    def __getitem__(self,key):# NOQA
         return self.__dict__.__getitem__(key)
 
     def __setattr__(self, key, value):
-        """ assigns a value, including functions which will becomes methods, e.g. the first argument must be 'self' """
+        """ Assigns a value, including functions which will becomes methods, e.g. the first argument must be 'self' """
         self.__setitem__(key,value)
 
     def __setitem__(self,key,value):
-        """ assigns a value, including functions which will becomes methods, e.g. the first argument must be 'self' """
+        """ Assigns a value, including functions which will becomes methods, e.g. the first argument must be 'self' """
         if isinstance(value,types.FunctionType):
             # bind function to this object
             value = types.MethodType(value,self)
@@ -347,31 +349,27 @@ class Generic(object):
             value = types.MethodType(value.__func__,self)
         self.__dict__.__setitem__(key,value)
         
-    def __len__(self):
+    def __len__(self):# NOQA
         return self.__dict__.__len__()
         
-    def __delitem__(self,key):
-        """ like dict """
+    def __delitem__(self,key):# NOQA
         self.__dict__.__delitem__(key)
 
-    def __iter__(self):
-        """ like dict """
+    def __iter__(self):# NOQA
         return self.__dict__.__iter__()
     
-    def __contains__(self, key):
-        """ implements 'in' operator """
+    def __contains__(self, key):# NOQA
         return self.__dict__.__contains__(key)
     
     def __call__(self, key, *kargs):
         """ Short-cut for get(), e.g. use __call__('a', 0) to ask for the value of 'a' with default 0 """
         return self.get(key,*kargs)
     
-    def keys(self):
-        """ like dict """
+    def keys(self):# NOQA
         return self.__dict__.keys()
 
     def get(self, key, *kargs):
-        """ like dict.get(), e.g. get('a',0) gets the value of 'a' defaulting to 0. If no default is proivded, and 'a' is not defined the function fails """
+        """ Like dict.get(), e.g. get('a',0) gets the value of 'a' defaulting to 0. If no default is proivded, and 'a' is not defined the function fails """
         if len(kargs) == 0 or key in self:
             return self[key]
         if len(kargs) != 1:
@@ -379,37 +377,44 @@ class Generic(object):
         return kargs[0]
     
     def __add__(self, o):
-        """ Allows merging dicts or other Generics into the Generic
-                g = Generic(a=1)
-                g += Generic(a=2,b=1)
-            or
-                g += {'a':2,'b':1)
-            gives a Generic witha=2,b=1.
+        """
+        Allows merging dicts or other Generics into the Generic
+            g = Generic(a=1)
+            g += Generic(a=2,b=1)
+        or
+            g += {'a':2,'b':1)
+        gives a Generic witha=2,b=1.
         """        
         if not isinstance(o,(dict,Generic)):
             raise ValueError("Cannot handle type %s. Use merge() explicitly to add object members" % type(o))
         return Generic(self,o)
     
     def update(self,*vargs,**kwargs):
-        """ merges various data into the generic.
-                varargs: for each element, add the key/value pairs of dictionaries, Generics or any object. For Generics, the function re-points methods
-                kwargs: are kwarg name/value pairs all added directly, e.g. merge(a=1) adds 'a' with a value of '1' to self
-                
-            Example
-                in1 = { 'a':1, 'b':2 }
-                in2 = Generic(c=3,d=4)
-                def F(self,x):
-                    self.d = x
-                in2.F = F   <-- creates a method
-                def O(object):
-                    def __init__(self):
-                        self.e = 5
-                in3 = O()                
-                update( in1, in2, in3, g=6 )
-                
-            Note
-                The function first processes the 'vargs' list, and then
-                any explicit keywords which will overwrite any duplicates
+        """ 
+        Merges various data into the generic.
+        
+        Parameters
+        ----------
+            varargs: 
+                for each element, add the key/value pairs of dictionaries, Generics or any object. For Generics, the function re-points methods
+            kwargs: 
+                are kwarg name/value pairs all added directly, e.g. merge(a=1) adds 'a' with a value of '1' to self
+            
+        Example
+            in1 = { 'a':1, 'b':2 }
+            in2 = Generic(c=3,d=4)
+            def F(self,x):
+                self.d = x
+            in2.F = F   <-- creates a method
+            def O(object):
+                def __init__(self):
+                    self.e = 5
+            in3 = O()                
+            update( in1, in2, in3, g=6 )
+            
+        Note
+            The function first processes the 'vargs' list, and then
+            any explicit keywords which will overwrite any duplicates
         """
         def merge_object_dict(o):
             """ Allows loading data elements from a list, another Generic or any object """
